@@ -1840,7 +1840,7 @@ class SixfabPower:
         Parameters
         -----------
         interval : int
-            time in minutes to trigger recovery actions (min : 2 , max : 180)
+            time in minutes to trigger recovery actions (min : 4 , max : 180)
         timeout : int (optional)
             timeout while receiving the response (default is RESPONSE_DELAY)
 
@@ -1850,8 +1850,8 @@ class SixfabPower:
             "1" for SET OK, "2" for SET FAILED
         """
 
-        if(interval < 2) or (interval > 255):
-            print("Wrong argument. min:2 max:255")
+        if(interval < 4) or (interval > 180):
+            print("Wrong argument. min:2 max:180")
             return 2
 
         command.create_set_command(
@@ -1923,9 +1923,9 @@ class SixfabPower:
         Parameters
         -----------
         sleep_time : int
-            time in [minutes]   ( min : 2 , max : 1440 )
+            time in [minutes]   ( min : 2 , max : 1439 )
         run_time : int
-            time in [minutes]   ( min : 2 , max : 1440 )   
+            time in [minutes]   ( min : 0 , max : 1437 )   
         timeout : int (optional)
             timeout while receiving the response (default is RESPONSE_DELAY)
         Returns
@@ -2034,7 +2034,7 @@ class SixfabPower:
         Parameters
         -----------
         threshold : int
-            current threshold in [mA] [min : 0 , max : 3000]
+            current threshold in [mA] (min : 0 , max : 3000)
         timeout : int (optional)
             timeout while receiving the response (default is RESPONSE_DELAY)
 
@@ -2055,53 +2055,18 @@ class SixfabPower:
         return status
 
 
-    def get_debug_config(self, timeout=RESPONSE_DELAY):
+    def restore_factory_defaults(self, timeout=RESPONSE_DELAY):
         """
-        Function for getting debugging configuration
+        Function for factory defaults
         
         Parameters
         -----------
-        timeout : int (optional)
-            timeout while receiving the response (default is RESPONSE_DELAY)
+        None
 
         Returns
         ------- 
-        status : int
-            "1" for ENABLED, "2" for DISABLED, "3" for ENABLED_WITH_TIMESTAMP 
+        None
         """
 
-        command.create_command(command.PROTOCOL_COMMAND_GET_DEBUG_CONFIG)
-        command.send_command()
-        delay_ms(timeout)
-        raw = command.receive_command(COMMAND_SIZE_FOR_UINT8)
-
-        status = raw[PROTOCOL_HEADER_SIZE]
-        return status
-
-
-    def set_debug_config(self, config, timeout=RESPONSE_DELAY):
-        """
-        Function for setting debugging configuration
-        
-        Parameters
-        -----------
-        config : int
-            "1" for ENABLED, "2" for DISABLED, "3" for ENABLED_WITH_TIMESTAMP
-        timeout : int (optional)
-            timeout while receiving the response (default is RESPONSE_DELAY)
-
-        Returns
-        ------- 
-        result : int
-            "1" for SET OK, "2" for SET FAILED
-        """
-
-        command.create_set_command(
-            command.PROTOCOL_COMMAND_SET_DEBUG_CONFIG, config, 1
-        )
-        command.send_command()
-        delay_ms(timeout)
-        raw = command.receive_command(COMMAND_SIZE_FOR_UINT8)
-
-        status = raw[PROTOCOL_HEADER_SIZE]
-        return status
\ No newline at end of file
+        command.create_command(command.PROTOCOL_COMMAND_RESTORE_FACTORY_SETTINGS)
+        command.send_command()
\ No newline at end of file
